#!/bin/bash

# sfwbar config
# GPLv2 (/usr/share/doc/legal)

CONF=$HOME/.config/sfwbar/extrabar.conf
rm -f /tmp/sfwlaunch*.lst

[ ! -f /usr/share/icons/hicolor/48x48/apps/desktop_tray_config.svg ] && \
ln -sf /usr/share/pixmaps/puppy/desktop_tray_config.svg /usr/share/icons/hicolor/48x48/apps && gtk-update-icon-cache -f -i /usr/share/icons/hicolor 2>/dev/null

#----------------------------- functions  -----------------------------#

current_launchbar_apps() {
    CLA=`cat $HOME/.config/sfwbar/extrabar.conf | cut -d'|' -f2 | grep -v '='`
    [ -z "$CLA" ] && CLA="No launchbar applications found"
    echo "$CLA" | Xdialog --fixed-font --title "Current Launchbar Applications" --no-cancel --textbox "-" 22 55 2>/dev/null &
}

parse_line() {
    N="$1"
    grep "${N}$" /tmp/sfwlaunch.lst >> /tmp/sfwlaunchCONF.lst
    grep "${N}" /tmp/sfwlaunchP.lst >> /tmp/sfwlaunchCONF.lst
}

move() { # https://wikka.puppylinux.com/gtkdialogDocTips9.7 - thanks ziggy!
    PRESS_EVENT=$(cat /tmp/sfwlaunchPRESS_EVENT)
    echo "p $PRESS_EVENT t $TREE" > /tmp/tree
    [[ $PRESS_EVENT && $TREE  ]] || return 
    [[ $PRESS_EVENT == $TREE  ]] && return 
    sed -i "/$PRESS_EVENT/d; /$TREE/ i\\$PRESS_EVENT" /tmp/sfwlaunchSEL.lst
}

restart_sfwbar() {
    SFWBAR_PID=$(pidof -s sfwbar)
    if [ -n "$SFWBAR_PID" ]; then
        kill -HUP $SFWBAR_PID
    else
        sfwbar &
    fi
}

launchbar_keep_yes() {
    gtkdialog-splash -bg darkgoldenrod -placement top -timeout 4 -text "$(gettext "Current launchbar apps will be used")" &
}

launchbar_keep_no() {
    gtkdialog-splash -bg darkgoldenrod -placement top -timeout 5 -text "$(gettext "Current launchbar apps disabled, please select new apps")" &
}

disable_launch() {
    sed -i '2s/true/false/' $HOME/.config/sfwbar/launcher.widget
}

disable_launch_notification() {
    gtkdialog-splash -bg darkgoldenrod -placement top -timeout 2 -text "$(gettext "Disabling launchbar")" &
}

enable_launch() {
    sed -i '2s/false/true/' $HOME/.config/sfwbar/launcher.widget
}

enable_launch_notification() {
    gtkdialog-splash -bg darkgoldenrod -placement top -timeout 2 -text "$(gettext "Enabling launchbar")" &
}

orient_bar() {
    #$1 = line no, $2 old pos, $3 = new pos
    sed -i "${1}s/$2/$3/" $HOME/.config/sfwbar/sfwbar.config
}

update_radii() {
    # $1 = old radius, $2 = new radius
    sed -i "s/border-radius.*$/border-radius: ${2}px;/g" $HOME/.config/sfwbar/sfwbar.config
    sed -i "s/border-radius.*$/border-radius: ${2}px;/g" $HOME/.config/sfwbar/launcher.css
}

update_menuitemsize() {
    # $1 = SFWbar new menu itemsize
    FontName=$(grep '{ font:' $HOME/.config/sfwbar/sfwbar.config | awk '{print $5}' | sed 's/;//')
    [ -z "$FontName" ] && FontName=Sans
    sed -i "s/{ font: .*$/{ font: ${1}pt ${FontName}; }/" $HOME/.config/sfwbar/sfwbar.config
    # sync Labwc menu itemsize with SFWbar new menu itemsize
    sed -i "/<font place=/,/font/ s/<size>.*<\/size>/<size>$1<\/size>/" $HOME/.config/labwc/rc.xml
    if [ "$GLOBAL" = "true" ]; then # apply new font size globally
        gsettings set org.gnome.desktop.interface font-name "$FontName $1"
        ptheme_gtk
    else # apply default font size globally (10pt)
        gsettings set org.gnome.desktop.interface font-name "$FontName 10"
        ptheme_gtk
    fi
    labwc -r
}

update_size() {
    # set icon size and exclusive zone
    case $1 in
        24)PX=24;MB=18;FntS=10;;
        28)PX=28;MB=22;FntS=10;;
        30)PX=30;MB=24;FntS=11;;
        36)PX=36;MB=30;FntS=12;;
        42)PX=42;MB=36;FntS=13;;
    esac
    IMGLN=$(grep -n 'button#taskbar_normal image' $HOME/.config/sfwbar/sfwbar.config)
    IMGNO=${IMGLN%\:button*}
    TWLN=$(($IMGNO + 2))
    THLN=$(($IMGNO + 3))
    sed -i \
           -e "s/font: \([0-9][0-9]\)pt Sans/font: ${FntS}pt Sans/" \
           -e "${TWLN}s/\([0-9][0-9]\)px/$((${PX}*2/3))px/" \
           -e "${THLN}s/\([0-9][0-9]\)px/$((${PX}*2/3))px/" \
        $HOME/.config/sfwbar/sfwbar.config
    for widget in $(ls $HOME/.config/sfwbar/|grep 'widget$'); do
        SZ=$(grep -m1 -o 'min.*width' $HOME/.config/sfwbar/$widget|grep -o '[0-9][0-9].*px')
        case $widget in
            clock*)sed -i "s/\([0-9][0-9]\)pt/${FntS}pt/g" $HOME/.config/sfwbar/$widget ;;
            cpu*|load*|memory*|swap*|disk*)
                sed -i "s/min-height: \([0-9][0-9]\)px\;/min-height: $((${PX} - 2))px\;/" $HOME/.config/sfwbar/$widget ;;
            'launcher.widget');;
            'buttonmenu.widget')
                sed -i -e "s/min-height: \([0-9][0-9]\)px/min-height: ${MB}px/"\
                    -e "s/min-width: \([0-9][0-9]\)px/min-width: $((${MB} * 4 / 3))px/"\
                    $HOME/.config/sfwbar/buttonmenu.widget
                    ;;
            *)sed -i "s/\([0-9][0-9]\)px/${PX}px/g" $HOME/.config/sfwbar/$widget ;;
        esac
    done

}

export -f parse_line move restart_sfwbar disable_launch disable_launch_notification enable_launch enable_launch_notification orient_bar update_radii update_size launchbar_keep_yes launchbar_keep_no current_launchbar_apps update_menuitemsize

#-------------------------------- main --------------------------------#
FULL=true # full gui

[ "$1" = '-r' ] && restart_sfwbar && exit
[ "$1" = '-f' ] && disable_launch && exit
[ "$1" = '-e' ] && enable_launch && exit
[ "$1" = '-fr' ] && disable_launch && restart_sfwbar && exit
[ "$1" = '-er' ] && enable_launch && restart_sfwbar && exit
[ "$1" = '-o' ] && orient_bar $2 $3 $4 && exit
[ "$1" = '-c' ] && FULL=false # cut down gui
[ "$1" = '-x' ] && update_radii $2 $3 && exit

read -d ':' TGT_LN z <<<$(grep -n '^window#panel' $HOME/.config/sfwbar/sfwbar.config)
read -d ';' x y TGT_STR <<<$(sed -n ${TGT_LN}p $HOME/.config/sfwbar/sfwbar.config)
DEF_BARPOS=${TGT_STR##*\ }
case $DEF_BARPOS in
    top)X_BARPOS=bottom;;
    bottom)X_BARPOS=top;;
esac

read -d ';' w x DEF_POS <<<$(grep -n 'window#launcher' $HOME/.config/sfwbar/sfwbar.config)
DEF_POS=${DEF_POS##*\ }
nn=0
for c in $DEF_POS top bottom left right ; do
    [ "$c" = "$DEF_POS" ] && [ $nn -gt 0 ] && continue
    CITEMS="${CITEMS}<item>$c</item>"
    nn=$((nn + 1))
done

while read mon; do
    MONS="${MONS}
        <item>${mon%\ *}</item>"
done <<< $(wlopm)

MNR=$(printf "$MONS" | wc -l)
if [ $MNR -gt 1 ]; then
    read xx yy DEF_MON0 <<<$(grep -m1 'SetMonitor "panel"' $HOME/.config/sfwbar/sfwbar.config|sed 's/\"//g') 
    MONS0="        <comboboxtext width-request="185">
            <item>$DEF_MON0</item>
            $(printf "%s\n" "$MONS"|grep -v $DEF_MON0)
          <variable>MON0</variable>
        </comboboxtext>"

    read xx yy DEF_MON1 <<<$(grep -m1 'SetMonitor "launcher"' $HOME/.config/sfwbar/sfwbar.config|sed 's/\"//g') 
    MONS1="        <comboboxtext width-request="185">
            <item>$DEF_MON1</item>
            $(printf "%s\n" "$MONS"|grep -v $DEF_MON1)
          <variable>MON1</variable>
        </comboboxtext>"
else
    MONS0='' MONS1=''
fi

DEFRAD_NR=$(grep -n 'button {' ~/.config/sfwbar/sfwbar.config)
read -d ';' j DEFRAD <<<$(sed -n $((${DEFRAD_NR%%\:*} + 3))p $HOME/.config/sfwbar/sfwbar.config)
DEFSIZE=$(grep -o 'min-width.*;' $HOME/.config/sfwbar/logout.widget|grep -o '[0-9][0-9]px')
[[ ! $(echo "$DEFRAD" | grep '[0-9]') ]] && DEFRAD=0
DEFRAD=${DEFRAD/px/}
DEFSIZE=${DEFSIZE/px/}

DEFLENGTH_NR=$(grep 'SetBarSize "panel"' $HOME/.config/sfwbar/sfwbar.config)
DEFLENGTH=$(echo $DEFLENGTH_NR | awk '{print $3}' | cut -d '"' -f2 | cut -d '"' -f1)
[ -z "$DEFLENGTH" ] && DEFLENGTH=100%

DEFITEMSIZE=$(grep '{ font:' $HOME/.config/sfwbar/sfwbar.config | awk '{print $4}' | sed 's/pt//g')
[ -z "$DEFITEMSIZE" ] && DEFITEMSIZE=10

GLOBAL=$(cat $HOME/.config/sfwbar/globalfont 2>/dev/null)
[ -z "$GLOBAL" ] && GLOBAL=false && echo $GLOBAL > $HOME/.config/sfwbar/globalfont

if [ "$FULL" = 'true' ]; then
    gtkdialog-splash -bg darkgoldenrod -close never -placement top -text "$(gettext "Processing, please wait...")" &
    gpid=$!

    # puppy apps
    defaulticons=`ls /usr/local/lib/X11/pixmaps/*48.png`
    for i in $defaulticons
    do ln -sf $i /usr/share/icons
    done
    for z in \
    'home48.png|defaultfilemanager|File' \
    'drive48.png|pmount|Mount' \
    'pet48.png|synaptic-pkexec|Install' \
    'configuration48.png|wizardwizard|Setup' \
    'console48.png|defaultterminal|Terminal' \
    'utility48.png|defaultprocessmanager|Process' \
    'edit48.png|defaulttexteditor|Edit' \
    'word48.png|defaultwordprocessor|Write' \
    'spread48.png|defaultspreadsheet|Calc' \
    'paint48.png|defaultpaint|Paint' \
    'www48.png|defaultbrowser|Browse' \
    'email48.png|defaultemail|Email' \
    'connect48.png|connectwizard|Connect' \
    'date48.png|defaultcalendar|Calendar' \
    'multimedia48.png|defaultmediaplayer|Play' \
    'help48.png|puppyhelp|Help' \
    'shutdown48.png|logout_gui|Exit'
    do
        [ -n "$z" ] && echo "$z" >> /tmp/sfwlaunchP.lst
        if [ -n "$z" ]; then
            read l m n <<<$(echo $z | tr '|' ' ')
            echo "$m ," >> /tmp/sfwlaunchPUP.lst
        fi
    done

    # main apps
    for i in /usr/share/applications/*; do
        grep -q "^NoDisplay=true" $i && continue
        grep -q "^Icon" $i || continue
        NAME="$(grep -m1 "^Name=" $i)"
        EXEC="$(grep -m1 "^Exec=" $i)"
        ICON="$(grep -m1 "^Icon=" $i)"
        # ignore full path, use icon theme only apps (mostly)
        echo ${ICON#*=} | grep -q '^/' && continue
        echo "${ICON#*=}|${EXEC#*=}|${NAME#*=}" >> /tmp/sfwlaunch.lst
        echo "${NAME#*=} ," >> /tmp/sfwlaunchGUI.lst
    done

    kill -9 $gpid

    EXTRAS='<text use-markup="true"><label>"'$(gettext "<b>Select LaunchBar Applications</b>")' "</label></text>
    <hbox space-expand="true" space-fill="true">
    <vbox space-expand="true" space-fill="true">
      <frame '$(gettext "Default Apps")'>
        <tree space-expand="true" space-fill="true" headers-clickable="false" selection-mode="3" tooltip-text=" '$(gettext "Press and hold Ctrl key for multiple selections")' ">
         <variable>SELECTIONSPUP</variable>
         <label>'$(gettext "Available Default Apps  (select 2-15)")'</label>
         <input>cat /tmp/sfwlaunchPUP.lst</input>
        </tree>
        <variable>CHOOSEPUP</variable>
      </frame>
    </vbox>
    <vbox space-expand="true" space-fill="true">
      <frame '$(gettext "Menu Apps")'>
        <tree space-expand="true" space-fill="true" headers-clickable="false" selection-mode="3" tooltip-text=" '$(gettext "Press and hold Ctrl key for multiple selections")' ">
         <variable>SELECTIONS</variable>
         <label>'$(gettext "Available Menu Apps  (select 2-15)")'</label>
         <input>cat /tmp/sfwlaunchGUI.lst</input>
        </tree>
        <variable>CHOOSE</variable>
        <sensitive>false</sensitive>
      </frame>
    </vbox>
    </hbox>'
    STOCKP='<checkbox tooltip-text=" '$(gettext "Disable this option to use Puppy menu apps")' ">
          <label>'$(gettext "Use Puppy default apps")'</label>
          <input>echo true</input>
          <variable>CHECK</variable>
          <action>echo IN=false</action>
          <action>refresh:KEEP</action>
          <action>if false disable:CHOOSEPUP</action>
          <action>if true enable:CHOOSEPUP</action>
          <action>if false enable:CHOOSE</action>
          <action>if true disable:CHOOSE</action>
        </checkbox>'
        IN='false'

else
    EXTRAS=''
    STOCKP=''
    IN='true'
fi
if grep -qm1 'false' $HOME/.config/sfwbar/launcher.widget ; then
    STATE=true
else
    STATE=false
fi
CSIZE=$(grep 'SIZE' $CONF|grep -o '[0-9][0-9]')

CLA=`cat $HOME/.config/sfwbar/extrabar.conf | cut -d'|' -f2 | grep -v '='` # test for current launchbar apps
[ -n "$CLA" ] && IN=true || IN=false

[ "$FULL" = "true" ] && HEIGHT="600" || HEIGHT=""

export GUI='<window title="SFWBar Configuration" icon-name="desktop_tray_config" window-position="1">
  <vbox height-request="'"$HEIGHT"'">
  <vbox space-expand="true" space-fill="true">
  '"`/usr/lib/gtkdialog/xml_info fixed "desktop_tray_config.svg" 60 "$(gettext 'Here you can change the properties of the taskbar and launchbar. The selected launchbar items remain unchanged while the <b>Keep Current Launchbar</b> option is enabled, or you can disable this option and populate a new launchbar with your choice of Puppy Default or Menu applications.')"`"' 
    <hbox space-expand="false" space-fill="false" homogeneous="true">
    <hbox space-expand="true" space-fill="true">
      <frame '$(gettext "TaskBar")'>
        <hbox>
            <text xalign="0"><label> '$(gettext "Screen position")'</label></text>
            <text space-expand="true" space-fill="true"><label>" "</label></text>
            <comboboxtext width-request="185" tooltip-text=" '$(gettext "Taskbar screen position")' ">
              <item>'$DEF_BARPOS'</item>
              <item>'$X_BARPOS'</item>
              <variable>BARPOS</variable>
            </comboboxtext>
            '$MONS0'
        </hbox>
        <hbox>
            <text xalign="0"><label> '$(gettext "Width & length")'</label></text>
            <text space-expand="true" space-fill="true"><label>" "</label></text>
            <comboboxtext width-request="90" tooltip-text=" '$(gettext "This option adjusts icon pixel size")' ">
              <default>'$DEFSIZE'</default>
              <item>24</item>
              <item>28</item>
              <item>30</item>
              <item>36</item>
              <item>42</item>
              <variable>NEWSIZE</variable>
            </comboboxtext>
            <comboboxtext width-request="90" tooltip-text=" '$(gettext "Taskbar length as percent of screen size")' ">
              <default>'$DEFLENGTH'</default>
              <item>100%</item>
              <item>90%</item>
              <item>80%</item>
              <item>70%</item>
              <variable>NEWLENGTH</variable>
            </comboboxtext>
        </hbox>
        <hbox space-expand="false" space-fill="false">
            <text xalign="0"><label> '$(gettext "Corner radius")'</label></text>
            <text space-expand="true" space-fill="true"><label>" "</label></text>
            <comboboxtext width-request="185" tooltip-text=" '$(gettext "Taskbar and Launchbar corner roundness  (0=square corners)")' ">
              <default>'$DEFRAD'</default>
              <item>0</item>
              <item>1</item>
              <item>2</item>
              <item>3</item>
              <item>4</item>
              <item>5</item>
              <item>6</item>
              <item>7</item>
              <item>8</item>
              <item>default</item>
              <variable>RAD</variable>
            </comboboxtext>
        </hbox>
        <hbox space-expand="false" space-fill="false">
            <text xalign="0"><label> '$(gettext "Font size")'</label></text>
            <text space-expand="true" space-fill="true"><label>" "</label></text>
            <checkbox tooltip-text=" '$(gettext "Apply selected font size globally to desktop environment")' ">
              <label>'$(gettext "Global")'</label>
              <input>echo '$GLOBAL'</input>
              <variable>GLOBAL</variable>
              <action>if true echo true > $HOME/.config/sfwbar/globalfont</action>
              <action>if false echo false > $HOME/.config/sfwbar/globalfont</action>
            </checkbox>
            <comboboxtext width-request="185" tooltip-text=" '$(gettext "Apply selected font size to taskbar and desktop menus")' ">
              <default>'$DEFITEMSIZE'</default>
              <item>10</item>
              <item>11</item>
              <item>12</item>
              <item>13</item>
              <item>14</item>
              <variable>NEWITEMSIZE</variable>
            </comboboxtext>
        </hbox>
        <variable>ITEMS</variable>
      </frame>
    </hbox>

    <hbox space-expand="true" space-fill="true">
    <frame '$(gettext "LaunchBar")'>
        <hbox>
            <text xalign="0"><label> '$(gettext "Position & width")'</label></text>
            <text space-expand="true" space-fill="true"><label>" "</label></text>
            <comboboxtext tooltip-text=" '$(gettext "Launchbar screen position")' ">
              '$CITEMS'
              <variable>POS</variable>
            </comboboxtext>
            <comboboxtext tooltip-text=" '$(gettext "This option adjusts icon pixel size")' ">
              <item>'$CSIZE'</item>
              <item>24</item>
              <item>32</item>
              <item>36</item>
              <item>42</item>
              <item>48</item>
              <item>56</item>
              <item>64</item>
              <variable>SIZE</variable>
            </comboboxtext>
            '$MONS1'
        </hbox>
        <hbox>
            <checkbox>
              <label>'$(gettext "Keep current launchbar")'</label>
              <input>echo '$IN'</input>
              <variable>KEEP</variable>
              <action>if true disable:CHOOSEPUP</action>
              <action>if true disable:CHOOSE</action>
              <action>if true launchbar_keep_yes &</action>
              <action>if false enable:CHOOSEPUP</action>
              <action>if false enable:CHOOSE</action>
              <action>if false launchbar_keep_no &</action>
            </checkbox>
            <text space-expand="true" space-fill="true"><label>" "</label></text>
            <button space-expand="false" space-fill="false" tooltip-text=" '$(gettext 'Current launchbar applications')' ">
              <label> '$(gettext "List")'</label>
              <action>current_launchbar_apps &</action>
            </button>
        </hbox>
        '$STOCKP'
        <text space-expand="false" space-fill="false"><label>" "</label></text>
        <hbox>
            <checkbox>
              <label>'$(gettext "Disable LaunchBar")'</label>
              <input>echo '$STATE'</input>
              <variable>DISABLE</variable>
              <action>if true disable:CHOOSEPUP</action>
              <action>if true disable:CHOOSE</action>
              <action>if true disable:POS</action>
              <action>if true disable:SIZE</action>
              <action>if true disable:KEEP</action>
              <action>if true disable:CHECK</action>
              <action>if true disable:MON1</action>
              <action>if true disable_launch_notification &</action>
              <action>if true disable_launch &</action>
              <action>if false enable:CHOOSEPUP</action>
              <action>if false enable:POS</action>
              <action>if false enable:SIZE</action>
              <action>if false enable:KEEP</action>
              <action>if false enable:CHECK</action>
              <action>if false enable:MON1</action>
              <action>if false enable_launch_notification &</action>
              <action>if false enable_launch &</action>
            </checkbox>
            <text space-expand="true" space-fill="true"><label>" "</label></text>
        </hbox>
        <variable>STOCK</variable>
      </frame>
    </hbox>
    </hbox>
    '$EXTRAS'
    <hbox space-expand="false" space-fill="false">
      <button width-request="35" space-expand="true" space-fill="true" tooltip-text=" '$(gettext 'Selection of light and dark desktop themes')' ">
        <label> '$(gettext "Global Themes")' </label>
        <action>ptheme_gtk_globalthemes &</action>
      </button>
      <button width-request="35" space-expand="true" space-fill="true" tooltip-text=" '$(gettext 'Change menu category icons')' ">
        <label> '$(gettext "Icon Switcher")' </label>
        <action>icon_switcher &</action>
      </button>
      <button width-request="35" space-expand="true" space-fill="true" tooltip-text=" '$(gettext 'Desktop configuration tool for Labwc compositor')' ">
        <label> '$(gettext "Labwc Tweaks")' </label>
        <action>labwc-tweaks-gtk-wrapper &</action>
      </button>
      <button width-request="35" space-expand="true" space-fill="true" tooltip-text=" '$(gettext 'Set desktop background')' ">
        <label> '$(gettext "Qwallpaper")' </label>
        <action>qwallpaper &</action>
      </button>
      <button width-request="35" space-expand="true" space-fill="true" tooltip-text=" '$(gettext 'Set taskbar digital clock')' ">
        <label> '$(gettext "SFWbar Clock")' </label>
        <action>sfwbar-clockset &</action>
      </button>
      <button ok></button>
    </hbox>
  </vbox>
  </vbox>
</window>'

. /usr/lib/gtkdialog/xml_info gtk #build bg_pixmap for gtk-theme
eval $(gtkdialog -p GUI --styles=/tmp/gtkrc_xml_info.css)
[ "$EXIT" = 'abort' ] && exit

if [ "$DEFRAD" != "$RAD" ]; then
    if [ $RAD = 'default' ]; then
        RAD=$(grep -o '<cornerRadius>.*[0-9]' ~/.config/labwc/rc.xml | tail -c2)
    fi
    update_radii $DEFRAD $RAD
fi

update_menuitemsize $NEWITEMSIZE

if [ "$DEFSIZE" != "$NEWSIZE" ]; then
    update_size $NEWSIZE
fi
if [ "$DEFLENGTH" != "$NEWLENGTH" ]; then
    sed -i "/SetBarSize \"panel\"/s/.*/  SetBarSize \"panel\", \"$NEWLENGTH\"/" $HOME/.config/sfwbar/sfwbar.config
fi
# bar
[ "$POS" = "$BARPOS" ] && \
    gtkdialog-splash -bg pink -close box -text "$(gettext "Error: Taskbar and launchbar postion must be different.")" && exit

if echo $TGT_STR | grep -qv "$BARPOS"; then
    orient_bar ${TGT_LN} $DEF_BARPOS $BARPOS #change orientation
fi
if ! grep -q "$BAR_MON" $HOME/.config/sfwbar/sfwbar.config ; then
    sed -i -e "s/#SetMonitor \"panel\".*$/SetMonitor \"panel\", \"$MON0\"/" -e "s/SetMonitor \"panel\".*$/SetMonitor \"panel\", \"$MON0\"/" $HOME/.config/sfwbar/sfwbar.config
fi

if [ "$DISABLE" = 'true' ]; then
    exec $0 -fr
elif [ "$DISABLE" = 'false' ]; then
    if [ "$KEEP" = 'false' ];then
        # launcher
        echo "POS=$POS" > /tmp/sfwlaunchCONF.lst
        echo "SIZE=$SIZE" >> /tmp/sfwlaunchCONF.lst
        [ -n "$MON1" ] && echo "MON1=$MON1" >> /tmp/sfwlaunchCONF.lst
        rm -f /tmp/sfwlaunchSEL.lst

        if [ -z "$SELECTIONS" -a "$CHECK" = 'false' ]; then
            gtkdialog-splash -bg pink -close box -text "$(gettext "Error: No apps chosen. Check 'Keep current launchbar' to restore the previous configuration.")" && exec $0
        elif [ -z "$SELECTIONSPUP" -a "$CHECK" = 'true' ]; then
            gtkdialog-splash -bg pink -close box -text "$(gettext "Error: No Puppy apps chosen. Check 'Keep current launchbar' to restore the previous configuration.")" exec $0
        fi

        # count the entries
        NR=0
        if [ "$CHECK" = 'true' ]; then
            # count the entries
            echo $SELECTIONSPUP | tr ',' '\n' | while read LINE ; do
                NR=$(($NR + 1))
                echo $NR > /tmp/NR
                echo "$LINE" >> /tmp/sfwlaunchSEL.lst
            done
        else
            echo $SELECTIONS | tr ',' '\n' | while read LINE ; do
                NR=$(($NR + 1))
                echo $NR > /tmp/NR
                echo "$LINE" >> /tmp/sfwlaunchSEL.lst
            done
        fi
        NR=$((`cat /tmp/NR` - 1))
        ([ $NR -gt 15 ] || [ $NR -lt 2 ]) && gtkdialog-splash -bg pink -close box -text "$(gettext "Error: $NR entries. Please choose 2 or more or 15 or less.")" && exec $0

        # confirm and re-order gui
        export CONFIRM='<window title="'$(gettext 'Confirm?')'" icon-name="sfwconfig">
          <vbox>
            <frame '$(gettext "Position")'>
              <text><label>'$POS'</label></text>
            </frame>
            <frame '$(gettext "Apps")'>
              <text><label>'$(gettext "You can re-order your apps here.")'</label></text>
              <tree headers-clickable="false" rules_hint="true" hover-selection="true" tooltip-text=" '$(gettext "Drag and drop items to move them in list")' ">
                <label>'$(gettext "Re-order the launcher Apps")'</label>
                <input>cat /tmp/sfwlaunchSEL.lst</input>
                <variable>TREE</variable>
                <height>300</height><width>200</width>
                <action signal="button-press-event">echo $TREE > /tmp/sfwlaunchPRESS_EVENT</action>
                <action signal="button-release-event">move</action>
                <action signal="button-release-event">refresh:TREE</action>
              </tree>
            </frame>
            <hbox><button cancel></button><button ok></button></hbox>
          </vbox>
        </window>'
        eval $(gtkdialog -p CONFIRM)
        
        case $EXIT in
            OK);;
            *)exit;;
        esac
        
        # write config
        while read PROG ; do
            [ -n "$PROG" ] && parse_line "$PROG"
        done < /tmp/sfwlaunchSEL.lst
        cat /tmp/sfwlaunchCONF.lst > $CONF
        sfwlauncher
    else
        sed -i "s/POS=.*$/POS=$POS/" $CONF
        sed -i "s/MON1=.*$/MON1=$MON1/" $CONF
        sed -i "s/SIZE=.*$/SIZE=$SIZE/" $CONF
        sed -i "s/SetMonitor \"panel\".*$/SetMonitor \"panel\", \"$MON0\"/" $HOME/.config/sfwbar/sfwbar.config
        if echo $TGT_STR | grep -qv "$BARPOS"; then
            orient_bar ${TGT_LN} $DEF_BARPOS $BARPOS #change orientation
        fi 
        sfwlauncher
    fi

    exec $0 -er
fi
